@@ -10,6 +10,65 @@ from com.inductiveautomation.ignition.common import BasicDataset
 from java.util import Date
 
 
+class _NanoXML(object):
+    def __init__(self, root="root", indent="\t"):
+        """Nano XML initializer.
+
+        Args:
+            root (str): The value of the XML root element.
+            indent (str): Character(s) used for indentation.
+        """
+        self.root = root
+        self.indent = indent
+        self._new_line = "\n"
+        self._output = "<{root}>{new_line}".format(
+            root=self.root, new_line=self._new_line
+        )
+
+    def add_element(self, name):
+        """Add an element to the XML document.
+
+        Args:
+            name (str): The name of the element.
+        """
+        self._output += "{indent}<{name}>{new_line}".format(
+            indent=self.indent, name=name, new_line=self._new_line
+        )
+
+    def add_sub_element(self, name, value):
+        """Add a sub element to an element.
+
+        Args:
+            name (str): The name of the sub element.
+            value (object): The value of the sub element.
+        """
+        self._output += "{indent}<{name}>{value}</{name}>{new_line}".format(
+            indent=self.indent * 2,
+            value=value,
+            new_line=self._new_line,
+            name=name,
+        )
+
+    def close_element(self, name):
+        """Close element.
+
+        Args:
+            name (str): The name of the element.
+        """
+        self._output += "{indent}</{name}>{new_line}".format(
+            indent=self.indent, name=name, new_line=self._new_line
+        )
+
+    def to_string(self):
+        """Return the string representation of the XML document.
+
+        Returns:
+            str: The string representation of the XML document.
+        """
+        self._output += "</{}>".format(self.root)
+        return self._output
+
+
 def _format_value(obj, header=None):
     """Format the value to be properly represented in JSON.
 
@@ -53,8 +112,7 @@ def _to_json(dataset, root, is_root=True):
     columns = dataset.getColumnCount()
     rows = dataset.getRowCount()
     data = system.dataset.toPyDataSet(dataset)
-    ret_str = "{" if is_root else ""
-    ret_str += '"{}":['.format(root)
+    ret_str = ("{" if is_root else "") + '"{}":['.format(root)
     col_count = 0
 
     for row_count, row in enumerate(data, start=1):
@@ -89,8 +147,8 @@ def to_json(dataset, root="json"):
     return _to_json(dataset, root)
 
 
-def to_xml(dataset, root="root", element="row"):
-    """Return a string XML representation of the Dataset.
+def to_xml(dataset, root="root", element="row", indent="\t"):
+    r"""Return a string XML representation of the Dataset.
 
     Args:
         dataset (BasicDataset): The input dataset.
@@ -98,23 +156,20 @@ def to_xml(dataset, root="root", element="row"):
             to "root". Optional.
         element (str): The value of the row. If not provided, it
             defaults to "row". Optional.
+        indent (str): Current indentation. If not provided, it defaults
+            to "\t". Optional.
 
     Returns:
         str: The string XML representation of the dataset.
     """
     headers = system.dataset.getColumnHeaders(dataset)
     data = system.dataset.toPyDataSet(dataset)
-    new_line = "\n"
-    tab = " " * 4
-    ret_str = "<{}>{}".format(root, new_line)
+    xml = _NanoXML(root, indent)
 
     for row in data:
-        ret_str += "{}<{}>{}".format(tab, element, new_line)
+        xml.add_element(element)
         for header in headers:
-            ret_str += "{0}<{header}>{1}</{header}>{2}".format(
-                tab * 2, row[header], new_line, header=header
-            )
-        ret_str += "{}</{}>{}".format(tab, element, new_line)
-    ret_str += "</{}>".format(root)
+            xml.add_sub_element(header, row[header])
+        xml.close_element(element)
 
-    return ret_str
+    return xml.to_string()
