@@ -6,8 +6,10 @@ __all__ = [
     "IncendiumUser",
     "get_emails",
     "get_user",
+    "get_user_email_address",
     "get_user_first_name",
     "get_user_full_name",
+    "get_users",
 ]
 
 import system.security
@@ -114,12 +116,12 @@ def get_emails(user_source="", filter_role=""):
         list[str]: A list of email addresses.
     """
     emails = set()
-
-    for user in system.user.getUsers(user_source):
-        _user = IncendiumUser(user)
-        for email in _user.email:
-            if filter_role and filter_role in _user.roles or not filter_role:
-                emails.add(email)
+    users = [
+        IncendiumUser(user) for user in get_users(user_source, filter_role)
+    ]
+    for user in users:
+        for email in user.email:
+            emails.add(email)
     return sorted(list(emails))
 
 
@@ -190,3 +192,25 @@ def get_user_full_name(user_source="", failover=None):
         str: The User's Full Name.
     """
     return get_user(user_source, failover).full_name
+
+
+def get_users(user_source="", filter_role=""):
+    """Get a list of PyUser objects from a User Source filtered by role.
+
+    Args:
+        user_source (str): The name of the User Source. If not provided,
+            the default User Source will be consulted. Optional.
+        filter_role (str): The name of the role. If provided, a list of
+            PyUser objects for users that are assigned to a matching
+            role will be retrieved, otherwise all users will be
+            retrieved as PyUser objects. Optional.
+
+    Returns:
+        list[PyUser]: A list of PyUser objects.
+    """
+    users = system.user.getUsers(user_source)
+    return (
+        [user for user in users if filter_role in user.getRoles()]
+        if filter_role
+        else users
+    )
